# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddShareRequestBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'name': 'str',
        'resources': 'list[str]',
        'access_mode': 'AccessMode',
        'embed': 'bool',
        'recipients': 'list[SharesRecipients]',
        'expiration': 'datetime',
        'has_notification': 'bool',
        'is_public': 'bool',
        'message_body': 'str',
        'notification_emails': 'list[str]',
        'password': 'str',
        'require_email': 'bool',
        'message_subject': 'str',
        'file_drop_create_folders': 'bool',
        'sending_local_files': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'name': 'name',
        'resources': 'resources',
        'access_mode': 'accessMode',
        'embed': 'embed',
        'recipients': 'recipients',
        'expiration': 'expiration',
        'has_notification': 'hasNotification',
        'is_public': 'isPublic',
        'message_body': 'messageBody',
        'notification_emails': 'notificationEmails',
        'password': 'password',
        'require_email': 'requireEmail',
        'message_subject': 'messageSubject',
        'file_drop_create_folders': 'fileDropCreateFolders',
        'sending_local_files': 'sendingLocalFiles'
    }

    def __init__(self, type=None, name=None, resources=None, access_mode=None, embed=None, recipients=None, expiration=None, has_notification=None, is_public=None, message_body=None, notification_emails=None, password=None, require_email=None, message_subject=None, file_drop_create_folders=None, sending_local_files=None):  # noqa: E501
        """AddShareRequestBody - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._name = None
        self._resources = None
        self._access_mode = None
        self._embed = None
        self._recipients = None
        self._expiration = None
        self._has_notification = None
        self._is_public = None
        self._message_body = None
        self._notification_emails = None
        self._password = None
        self._require_email = None
        self._message_subject = None
        self._file_drop_create_folders = None
        self._sending_local_files = None
        self.discriminator = None
        self.type = type
        self.name = name
        if resources is not None:
            self.resources = resources
        if access_mode is not None:
            self.access_mode = access_mode
        if embed is not None:
            self.embed = embed
        if recipients is not None:
            self.recipients = recipients
        if expiration is not None:
            self.expiration = expiration
        if has_notification is not None:
            self.has_notification = has_notification
        if is_public is not None:
            self.is_public = is_public
        if message_body is not None:
            self.message_body = message_body
        if notification_emails is not None:
            self.notification_emails = notification_emails
        if password is not None:
            self.password = password
        if require_email is not None:
            self.require_email = require_email
        if message_subject is not None:
            self.message_subject = message_subject
        if file_drop_create_folders is not None:
            self.file_drop_create_folders = file_drop_create_folders
        if sending_local_files is not None:
            self.sending_local_files = sending_local_files

    @property
    def type(self):
        """Gets the type of this AddShareRequestBody.  # noqa: E501

        The type of share to create. See above for a description of each.  # noqa: E501

        :return: The type of this AddShareRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AddShareRequestBody.

        The type of share to create. See above for a description of each.  # noqa: E501

        :param type: The type of this AddShareRequestBody.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["shared_folder", "receive", "send"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def name(self):
        """Gets the name of this AddShareRequestBody.  # noqa: E501

        A name for the share. This will be visible on the page that recipients visit.   # noqa: E501

        :return: The name of this AddShareRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AddShareRequestBody.

        A name for the share. This will be visible on the page that recipients visit.   # noqa: E501

        :param name: The name of this AddShareRequestBody.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def resources(self):
        """Gets the resources of this AddShareRequestBody.  # noqa: E501

        Array of resources for this share. See details on [how to specify resources](#section/Identifying-Resources) above.  **shared_folder** and **receive** shares must have only one `resource`, which is a directory that does not have a current share attached.  **send** shares may have multiple `resource` parameters. You can also leave this parameter null if you are planning to upload files to the send. If you are planning to upload files to the send that are not yet in your account, you will also need to call the [POST /shares/complete-send/{id}](#operation/completeDirectSend) endpoint to finish the send operation.   # noqa: E501

        :return: The resources of this AddShareRequestBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this AddShareRequestBody.

        Array of resources for this share. See details on [how to specify resources](#section/Identifying-Resources) above.  **shared_folder** and **receive** shares must have only one `resource`, which is a directory that does not have a current share attached.  **send** shares may have multiple `resource` parameters. You can also leave this parameter null if you are planning to upload files to the send. If you are planning to upload files to the send that are not yet in your account, you will also need to call the [POST /shares/complete-send/{id}](#operation/completeDirectSend) endpoint to finish the send operation.   # noqa: E501

        :param resources: The resources of this AddShareRequestBody.  # noqa: E501
        :type: list[str]
        """

        self._resources = resources

    @property
    def access_mode(self):
        """Gets the access_mode of this AddShareRequestBody.  # noqa: E501


        :return: The access_mode of this AddShareRequestBody.  # noqa: E501
        :rtype: AccessMode
        """
        return self._access_mode

    @access_mode.setter
    def access_mode(self, access_mode):
        """Sets the access_mode of this AddShareRequestBody.


        :param access_mode: The access_mode of this AddShareRequestBody.  # noqa: E501
        :type: AccessMode
        """

        self._access_mode = access_mode

    @property
    def embed(self):
        """Gets the embed of this AddShareRequestBody.  # noqa: E501

        Whether this share can be embedded within a web page.  # noqa: E501

        :return: The embed of this AddShareRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._embed

    @embed.setter
    def embed(self, embed):
        """Sets the embed of this AddShareRequestBody.

        Whether this share can be embedded within a web page.  # noqa: E501

        :param embed: The embed of this AddShareRequestBody.  # noqa: E501
        :type: bool
        """

        self._embed = embed

    @property
    def recipients(self):
        """Gets the recipients of this AddShareRequestBody.  # noqa: E501

        People you want to invite to the share. **Note**: unless you also set the `messageSubject` and `messageBody` for the new share, invitation emails will not be sent to these recipients.  # noqa: E501

        :return: The recipients of this AddShareRequestBody.  # noqa: E501
        :rtype: list[SharesRecipients]
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this AddShareRequestBody.

        People you want to invite to the share. **Note**: unless you also set the `messageSubject` and `messageBody` for the new share, invitation emails will not be sent to these recipients.  # noqa: E501

        :param recipients: The recipients of this AddShareRequestBody.  # noqa: E501
        :type: list[SharesRecipients]
        """

        self._recipients = recipients

    @property
    def expiration(self):
        """Gets the expiration of this AddShareRequestBody.  # noqa: E501

        Expiration date for the share. If someone attempts to use the share after this date, they will receive an error that the share is not available.  # noqa: E501

        :return: The expiration of this AddShareRequestBody.  # noqa: E501
        :rtype: datetime
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this AddShareRequestBody.

        Expiration date for the share. If someone attempts to use the share after this date, they will receive an error that the share is not available.  # noqa: E501

        :param expiration: The expiration of this AddShareRequestBody.  # noqa: E501
        :type: datetime
        """

        self._expiration = expiration

    @property
    def has_notification(self):
        """Gets the has_notification of this AddShareRequestBody.  # noqa: E501

        Whether delivery receipts should be sent.  # noqa: E501

        :return: The has_notification of this AddShareRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._has_notification

    @has_notification.setter
    def has_notification(self, has_notification):
        """Sets the has_notification of this AddShareRequestBody.

        Whether delivery receipts should be sent.  # noqa: E501

        :param has_notification: The has_notification of this AddShareRequestBody.  # noqa: E501
        :type: bool
        """

        self._has_notification = has_notification

    @property
    def is_public(self):
        """Gets the is_public of this AddShareRequestBody.  # noqa: E501

        Whether someone can visit the share without following a personalized recipient link.  # noqa: E501

        :return: The is_public of this AddShareRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this AddShareRequestBody.

        Whether someone can visit the share without following a personalized recipient link.  # noqa: E501

        :param is_public: The is_public of this AddShareRequestBody.  # noqa: E501
        :type: bool
        """

        self._is_public = is_public

    @property
    def message_body(self):
        """Gets the message_body of this AddShareRequestBody.  # noqa: E501

        The message to be included in email invitations for your recipients. Ignored if you have not also provided `recipients` and `messageSubject`  # noqa: E501

        :return: The message_body of this AddShareRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._message_body

    @message_body.setter
    def message_body(self, message_body):
        """Sets the message_body of this AddShareRequestBody.

        The message to be included in email invitations for your recipients. Ignored if you have not also provided `recipients` and `messageSubject`  # noqa: E501

        :param message_body: The message_body of this AddShareRequestBody.  # noqa: E501
        :type: str
        """

        self._message_body = message_body

    @property
    def notification_emails(self):
        """Gets the notification_emails of this AddShareRequestBody.  # noqa: E501

        Emails that will receive delivery receipts for this share. `hasNotification` must be **true** for delivery receipts will be sent.  # noqa: E501

        :return: The notification_emails of this AddShareRequestBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._notification_emails

    @notification_emails.setter
    def notification_emails(self, notification_emails):
        """Sets the notification_emails of this AddShareRequestBody.

        Emails that will receive delivery receipts for this share. `hasNotification` must be **true** for delivery receipts will be sent.  # noqa: E501

        :param notification_emails: The notification_emails of this AddShareRequestBody.  # noqa: E501
        :type: list[str]
        """

        self._notification_emails = notification_emails

    @property
    def password(self):
        """Gets the password of this AddShareRequestBody.  # noqa: E501

        Set a password for recipients to access the share. All recipients will use the same password.  # noqa: E501

        :return: The password of this AddShareRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this AddShareRequestBody.

        Set a password for recipients to access the share. All recipients will use the same password.  # noqa: E501

        :param password: The password of this AddShareRequestBody.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def require_email(self):
        """Gets the require_email of this AddShareRequestBody.  # noqa: E501

        True if recipients must provide their email to view the share.  # noqa: E501

        :return: The require_email of this AddShareRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._require_email

    @require_email.setter
    def require_email(self, require_email):
        """Sets the require_email of this AddShareRequestBody.

        True if recipients must provide their email to view the share.  # noqa: E501

        :param require_email: The require_email of this AddShareRequestBody.  # noqa: E501
        :type: bool
        """

        self._require_email = require_email

    @property
    def message_subject(self):
        """Gets the message_subject of this AddShareRequestBody.  # noqa: E501

        Subject to use on emails inviting recipients to the share. Ignored if you have not also provided `recipients` and a `messageBody`  # noqa: E501

        :return: The message_subject of this AddShareRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._message_subject

    @message_subject.setter
    def message_subject(self, message_subject):
        """Sets the message_subject of this AddShareRequestBody.

        Subject to use on emails inviting recipients to the share. Ignored if you have not also provided `recipients` and a `messageBody`  # noqa: E501

        :param message_subject: The message_subject of this AddShareRequestBody.  # noqa: E501
        :type: str
        """

        self._message_subject = message_subject

    @property
    def file_drop_create_folders(self):
        """Gets the file_drop_create_folders of this AddShareRequestBody.  # noqa: E501

        Only used for **receive** shares. If true, uploads will be automatically placed into sub-folders of the folder, named after the chosen field on your form.   # noqa: E501

        :return: The file_drop_create_folders of this AddShareRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._file_drop_create_folders

    @file_drop_create_folders.setter
    def file_drop_create_folders(self, file_drop_create_folders):
        """Sets the file_drop_create_folders of this AddShareRequestBody.

        Only used for **receive** shares. If true, uploads will be automatically placed into sub-folders of the folder, named after the chosen field on your form.   # noqa: E501

        :param file_drop_create_folders: The file_drop_create_folders of this AddShareRequestBody.  # noqa: E501
        :type: bool
        """

        self._file_drop_create_folders = file_drop_create_folders

    @property
    def sending_local_files(self):
        """Gets the sending_local_files of this AddShareRequestBody.  # noqa: E501

        Use this only for **send** shares. Flag to indicate that you are going to upload additional files from your computer to the share. If this is **true**, you will also need to use the [POST /shares/complete-send/{id}](#operation/completeDirectSend) call to finish setting up your share after the files are uploaded.  # noqa: E501

        :return: The sending_local_files of this AddShareRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._sending_local_files

    @sending_local_files.setter
    def sending_local_files(self, sending_local_files):
        """Sets the sending_local_files of this AddShareRequestBody.

        Use this only for **send** shares. Flag to indicate that you are going to upload additional files from your computer to the share. If this is **true**, you will also need to use the [POST /shares/complete-send/{id}](#operation/completeDirectSend) call to finish setting up your share after the files are uploaded.  # noqa: E501

        :param sending_local_files: The sending_local_files of this AddShareRequestBody.  # noqa: E501
        :type: bool
        """

        self._sending_local_files = sending_local_files

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddShareRequestBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddShareRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResourceAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hash': 'str',
        'name': 'str',
        'extension': 'str',
        'type': 'str',
        'created_by': 'str',
        'upload_date': 'datetime',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'accessed_at': 'datetime',
        'created_time': 'int',
        'updated_time': 'int',
        'accessed_time': 'int',
        'path': 'str',
        'size': 'int',
        'file_count': 'int',
        'previewable': 'bool'
    }

    attribute_map = {
        'hash': 'hash',
        'name': 'name',
        'extension': 'extension',
        'type': 'type',
        'created_by': 'createdBy',
        'upload_date': 'uploadDate',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'accessed_at': 'accessedAt',
        'created_time': 'createdTime',
        'updated_time': 'updatedTime',
        'accessed_time': 'accessedTime',
        'path': 'path',
        'size': 'size',
        'file_count': 'fileCount',
        'previewable': 'previewable'
    }

    def __init__(self, hash=None, name=None, extension=None, type=None, created_by=None, upload_date=None, created_at=None, updated_at=None, accessed_at=None, created_time=None, updated_time=None, accessed_time=None, path=None, size=None, file_count=None, previewable=None):  # noqa: E501
        """ResourceAttributes - a model defined in Swagger"""  # noqa: E501
        self._hash = None
        self._name = None
        self._extension = None
        self._type = None
        self._created_by = None
        self._upload_date = None
        self._created_at = None
        self._updated_at = None
        self._accessed_at = None
        self._created_time = None
        self._updated_time = None
        self._accessed_time = None
        self._path = None
        self._size = None
        self._file_count = None
        self._previewable = None
        self.discriminator = None
        if hash is not None:
            self.hash = hash
        if name is not None:
            self.name = name
        if extension is not None:
            self.extension = extension
        if type is not None:
            self.type = type
        if created_by is not None:
            self.created_by = created_by
        if upload_date is not None:
            self.upload_date = upload_date
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if accessed_at is not None:
            self.accessed_at = accessed_at
        if created_time is not None:
            self.created_time = created_time
        if updated_time is not None:
            self.updated_time = updated_time
        if accessed_time is not None:
            self.accessed_time = accessed_time
        if path is not None:
            self.path = path
        if size is not None:
            self.size = size
        if file_count is not None:
            self.file_count = file_count
        if previewable is not None:
            self.previewable = previewable

    @property
    def hash(self):
        """Gets the hash of this ResourceAttributes.  # noqa: E501

        Unique hash of the resource.  # noqa: E501

        :return: The hash of this ResourceAttributes.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this ResourceAttributes.

        Unique hash of the resource.  # noqa: E501

        :param hash: The hash of this ResourceAttributes.  # noqa: E501
        :type: str
        """

        self._hash = hash

    @property
    def name(self):
        """Gets the name of this ResourceAttributes.  # noqa: E501

        Resource name, e.g. the name of the file or folder.  # noqa: E501

        :return: The name of this ResourceAttributes.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ResourceAttributes.

        Resource name, e.g. the name of the file or folder.  # noqa: E501

        :param name: The name of this ResourceAttributes.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def extension(self):
        """Gets the extension of this ResourceAttributes.  # noqa: E501

        Resource extension. Property exists only if resource `type` is file.  # noqa: E501

        :return: The extension of this ResourceAttributes.  # noqa: E501
        :rtype: str
        """
        return self._extension

    @extension.setter
    def extension(self, extension):
        """Sets the extension of this ResourceAttributes.

        Resource extension. Property exists only if resource `type` is file.  # noqa: E501

        :param extension: The extension of this ResourceAttributes.  # noqa: E501
        :type: str
        """

        self._extension = extension

    @property
    def type(self):
        """Gets the type of this ResourceAttributes.  # noqa: E501

        Type of the resource.  # noqa: E501

        :return: The type of this ResourceAttributes.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ResourceAttributes.

        Type of the resource.  # noqa: E501

        :param type: The type of this ResourceAttributes.  # noqa: E501
        :type: str
        """
        allowed_values = ["file", "dir"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def created_by(self):
        """Gets the created_by of this ResourceAttributes.  # noqa: E501

        Username of the creator.  # noqa: E501

        :return: The created_by of this ResourceAttributes.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ResourceAttributes.

        Username of the creator.  # noqa: E501

        :param created_by: The created_by of this ResourceAttributes.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def upload_date(self):
        """Gets the upload_date of this ResourceAttributes.  # noqa: E501

        Timestamp of resource upload.  # noqa: E501

        :return: The upload_date of this ResourceAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._upload_date

    @upload_date.setter
    def upload_date(self, upload_date):
        """Sets the upload_date of this ResourceAttributes.

        Timestamp of resource upload.  # noqa: E501

        :param upload_date: The upload_date of this ResourceAttributes.  # noqa: E501
        :type: datetime
        """

        self._upload_date = upload_date

    @property
    def created_at(self):
        """Gets the created_at of this ResourceAttributes.  # noqa: E501

        Date-time of resource creation.  # noqa: E501

        :return: The created_at of this ResourceAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ResourceAttributes.

        Date-time of resource creation.  # noqa: E501

        :param created_at: The created_at of this ResourceAttributes.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this ResourceAttributes.  # noqa: E501

        Date-time of resource modification.  # noqa: E501

        :return: The updated_at of this ResourceAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ResourceAttributes.

        Date-time of resource modification.  # noqa: E501

        :param updated_at: The updated_at of this ResourceAttributes.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def accessed_at(self):
        """Gets the accessed_at of this ResourceAttributes.  # noqa: E501

        Date-time of the time when resource was accessed.  # noqa: E501

        :return: The accessed_at of this ResourceAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._accessed_at

    @accessed_at.setter
    def accessed_at(self, accessed_at):
        """Sets the accessed_at of this ResourceAttributes.

        Date-time of the time when resource was accessed.  # noqa: E501

        :param accessed_at: The accessed_at of this ResourceAttributes.  # noqa: E501
        :type: datetime
        """

        self._accessed_at = accessed_at

    @property
    def created_time(self):
        """Gets the created_time of this ResourceAttributes.  # noqa: E501

        UNIX timestamp of resource creation  # noqa: E501

        :return: The created_time of this ResourceAttributes.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this ResourceAttributes.

        UNIX timestamp of resource creation  # noqa: E501

        :param created_time: The created_time of this ResourceAttributes.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def updated_time(self):
        """Gets the updated_time of this ResourceAttributes.  # noqa: E501

        UNIX timestamp of resource modification  # noqa: E501

        :return: The updated_time of this ResourceAttributes.  # noqa: E501
        :rtype: int
        """
        return self._updated_time

    @updated_time.setter
    def updated_time(self, updated_time):
        """Sets the updated_time of this ResourceAttributes.

        UNIX timestamp of resource modification  # noqa: E501

        :param updated_time: The updated_time of this ResourceAttributes.  # noqa: E501
        :type: int
        """

        self._updated_time = updated_time

    @property
    def accessed_time(self):
        """Gets the accessed_time of this ResourceAttributes.  # noqa: E501

        UNIX timestamp of last access  # noqa: E501

        :return: The accessed_time of this ResourceAttributes.  # noqa: E501
        :rtype: int
        """
        return self._accessed_time

    @accessed_time.setter
    def accessed_time(self, accessed_time):
        """Sets the accessed_time of this ResourceAttributes.

        UNIX timestamp of last access  # noqa: E501

        :param accessed_time: The accessed_time of this ResourceAttributes.  # noqa: E501
        :type: int
        """

        self._accessed_time = accessed_time

    @property
    def path(self):
        """Gets the path of this ResourceAttributes.  # noqa: E501

        Full path to the resource.  # noqa: E501

        :return: The path of this ResourceAttributes.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this ResourceAttributes.

        Full path to the resource.  # noqa: E501

        :param path: The path of this ResourceAttributes.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def size(self):
        """Gets the size of this ResourceAttributes.  # noqa: E501

        Resource size in bytes  # noqa: E501

        :return: The size of this ResourceAttributes.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ResourceAttributes.

        Resource size in bytes  # noqa: E501

        :param size: The size of this ResourceAttributes.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def file_count(self):
        """Gets the file_count of this ResourceAttributes.  # noqa: E501

        Number of files within folder. null if resource type is a file.  # noqa: E501

        :return: The file_count of this ResourceAttributes.  # noqa: E501
        :rtype: int
        """
        return self._file_count

    @file_count.setter
    def file_count(self, file_count):
        """Sets the file_count of this ResourceAttributes.

        Number of files within folder. null if resource type is a file.  # noqa: E501

        :param file_count: The file_count of this ResourceAttributes.  # noqa: E501
        :type: int
        """

        self._file_count = file_count

    @property
    def previewable(self):
        """Gets the previewable of this ResourceAttributes.  # noqa: E501

        Can resource be previewed. Property equals `null` if resource `type` is dir.  # noqa: E501

        :return: The previewable of this ResourceAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._previewable

    @previewable.setter
    def previewable(self, previewable):
        """Sets the previewable of this ResourceAttributes.

        Can resource be previewed. Property equals `null` if resource `type` is dir.  # noqa: E501

        :param previewable: The previewable of this ResourceAttributes.  # noqa: E501
        :type: bool
        """

        self._previewable = previewable

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResourceAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NotificationAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'str',
        'type': 'str',
        'path': 'str',
        'name': 'str',
        'action': 'str',
        'usernames': 'list[str]',
        'recipients': 'list[NotificationRecipient]',
        'send_email': 'bool',
        'readable_description': 'str',
        'readable_description_without_path': 'str',
        'share_id': 'str',
        'message': 'str',
        'created': 'datetime',
        'modified': 'datetime'
    }

    attribute_map = {
        'user_id': 'userId',
        'type': 'type',
        'path': 'path',
        'name': 'name',
        'action': 'action',
        'usernames': 'usernames',
        'recipients': 'recipients',
        'send_email': 'sendEmail',
        'readable_description': 'readableDescription',
        'readable_description_without_path': 'readableDescriptionWithoutPath',
        'share_id': 'shareId',
        'message': 'message',
        'created': 'created',
        'modified': 'modified'
    }

    def __init__(self, user_id=None, type=None, path=None, name=None, action=None, usernames=None, recipients=None, send_email=None, readable_description=None, readable_description_without_path=None, share_id=None, message=None, created=None, modified=None):  # noqa: E501
        """NotificationAttributes - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._type = None
        self._path = None
        self._name = None
        self._action = None
        self._usernames = None
        self._recipients = None
        self._send_email = None
        self._readable_description = None
        self._readable_description_without_path = None
        self._share_id = None
        self._message = None
        self._created = None
        self._modified = None
        self.discriminator = None
        if user_id is not None:
            self.user_id = user_id
        if type is not None:
            self.type = type
        if path is not None:
            self.path = path
        if name is not None:
            self.name = name
        if action is not None:
            self.action = action
        if usernames is not None:
            self.usernames = usernames
        if recipients is not None:
            self.recipients = recipients
        if send_email is not None:
            self.send_email = send_email
        if readable_description is not None:
            self.readable_description = readable_description
        if readable_description_without_path is not None:
            self.readable_description_without_path = readable_description_without_path
        if share_id is not None:
            self.share_id = share_id
        if message is not None:
            self.message = message
        if created is not None:
            self.created = created
        if modified is not None:
            self.modified = modified

    @property
    def user_id(self):
        """Gets the user_id of this NotificationAttributes.  # noqa: E501

        ID of the user that the notification belongs to.  # noqa: E501

        :return: The user_id of this NotificationAttributes.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this NotificationAttributes.

        ID of the user that the notification belongs to.  # noqa: E501

        :param user_id: The user_id of this NotificationAttributes.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def type(self):
        """Gets the type of this NotificationAttributes.  # noqa: E501

        Type of the resource the notification is attached to.   # noqa: E501

        :return: The type of this NotificationAttributes.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this NotificationAttributes.

        Type of the resource the notification is attached to.   # noqa: E501

        :param type: The type of this NotificationAttributes.  # noqa: E501
        :type: str
        """
        allowed_values = ["file", "folder", "shared_folder", "send_receipt", "share_receipt", "file_drop"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def path(self):
        """Gets the path of this NotificationAttributes.  # noqa: E501

        Path to the item that the notification is set on.  # noqa: E501

        :return: The path of this NotificationAttributes.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this NotificationAttributes.

        Path to the item that the notification is set on.  # noqa: E501

        :param path: The path of this NotificationAttributes.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def name(self):
        """Gets the name of this NotificationAttributes.  # noqa: E501

        Name of the item that the notification is set on.  # noqa: E501

        :return: The name of this NotificationAttributes.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NotificationAttributes.

        Name of the item that the notification is set on.  # noqa: E501

        :param name: The name of this NotificationAttributes.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def action(self):
        """Gets the action of this NotificationAttributes.  # noqa: E501

        Action that triggers notification.  # noqa: E501

        :return: The action of this NotificationAttributes.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this NotificationAttributes.

        Action that triggers notification.  # noqa: E501

        :param action: The action of this NotificationAttributes.  # noqa: E501
        :type: str
        """
        allowed_values = ["upload", "download", "delete", "all"]  # noqa: E501
        if action not in allowed_values:
            raise ValueError(
                "Invalid value for `action` ({0}), must be one of {1}"  # noqa: E501
                .format(action, allowed_values)
            )

        self._action = action

    @property
    def usernames(self):
        """Gets the usernames of this NotificationAttributes.  # noqa: E501

        Detail on which users can trigger the notification.  # noqa: E501

        :return: The usernames of this NotificationAttributes.  # noqa: E501
        :rtype: list[str]
        """
        return self._usernames

    @usernames.setter
    def usernames(self, usernames):
        """Sets the usernames of this NotificationAttributes.

        Detail on which users can trigger the notification.  # noqa: E501

        :param usernames: The usernames of this NotificationAttributes.  # noqa: E501
        :type: list[str]
        """

        self._usernames = usernames

    @property
    def recipients(self):
        """Gets the recipients of this NotificationAttributes.  # noqa: E501

        Notification recipients.  # noqa: E501

        :return: The recipients of this NotificationAttributes.  # noqa: E501
        :rtype: list[NotificationRecipient]
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this NotificationAttributes.

        Notification recipients.  # noqa: E501

        :param recipients: The recipients of this NotificationAttributes.  # noqa: E501
        :type: list[NotificationRecipient]
        """

        self._recipients = recipients

    @property
    def send_email(self):
        """Gets the send_email of this NotificationAttributes.  # noqa: E501

        Whether or not an email will send when the notification is triggered.  # noqa: E501

        :return: The send_email of this NotificationAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._send_email

    @send_email.setter
    def send_email(self, send_email):
        """Sets the send_email of this NotificationAttributes.

        Whether or not an email will send when the notification is triggered.  # noqa: E501

        :param send_email: The send_email of this NotificationAttributes.  # noqa: E501
        :type: bool
        """

        self._send_email = send_email

    @property
    def readable_description(self):
        """Gets the readable_description of this NotificationAttributes.  # noqa: E501

        Human readable description of the notification.  # noqa: E501

        :return: The readable_description of this NotificationAttributes.  # noqa: E501
        :rtype: str
        """
        return self._readable_description

    @readable_description.setter
    def readable_description(self, readable_description):
        """Sets the readable_description of this NotificationAttributes.

        Human readable description of the notification.  # noqa: E501

        :param readable_description: The readable_description of this NotificationAttributes.  # noqa: E501
        :type: str
        """

        self._readable_description = readable_description

    @property
    def readable_description_without_path(self):
        """Gets the readable_description_without_path of this NotificationAttributes.  # noqa: E501

        Human readable description of the notification without item path.  # noqa: E501

        :return: The readable_description_without_path of this NotificationAttributes.  # noqa: E501
        :rtype: str
        """
        return self._readable_description_without_path

    @readable_description_without_path.setter
    def readable_description_without_path(self, readable_description_without_path):
        """Sets the readable_description_without_path of this NotificationAttributes.

        Human readable description of the notification without item path.  # noqa: E501

        :param readable_description_without_path: The readable_description_without_path of this NotificationAttributes.  # noqa: E501
        :type: str
        """

        self._readable_description_without_path = readable_description_without_path

    @property
    def share_id(self):
        """Gets the share_id of this NotificationAttributes.  # noqa: E501

        ID of the share that the notification belogns to.  # noqa: E501

        :return: The share_id of this NotificationAttributes.  # noqa: E501
        :rtype: str
        """
        return self._share_id

    @share_id.setter
    def share_id(self, share_id):
        """Sets the share_id of this NotificationAttributes.

        ID of the share that the notification belogns to.  # noqa: E501

        :param share_id: The share_id of this NotificationAttributes.  # noqa: E501
        :type: str
        """

        self._share_id = share_id

    @property
    def message(self):
        """Gets the message of this NotificationAttributes.  # noqa: E501

        Custom message that will be sent to the notification recipients.  # noqa: E501

        :return: The message of this NotificationAttributes.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this NotificationAttributes.

        Custom message that will be sent to the notification recipients.  # noqa: E501

        :param message: The message of this NotificationAttributes.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def created(self):
        """Gets the created of this NotificationAttributes.  # noqa: E501

        Timestamp of notifiction creation.  # noqa: E501

        :return: The created of this NotificationAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this NotificationAttributes.

        Timestamp of notifiction creation.  # noqa: E501

        :param created: The created of this NotificationAttributes.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def modified(self):
        """Gets the modified of this NotificationAttributes.  # noqa: E501

        Timestamp of notification modification.  # noqa: E501

        :return: The modified of this NotificationAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this NotificationAttributes.

        Timestamp of notification modification.  # noqa: E501

        :param modified: The modified of this NotificationAttributes.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotificationAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from exavault.api_client import ApiClient


class EmailApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def send_referral_email(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Send referral email to a given address  # noqa: E501

        Invite a friend to sign up for a free trial of ExaVault. Send a [referral](/lp/referafriend/) email to an email address. If the recipient signs up for ExaVault, we'll apply a credit to your account for the referral.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_referral_email(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param SendReferralEmailRequestBody body:
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_referral_email_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.send_referral_email_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def send_referral_email_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Send referral email to a given address  # noqa: E501

        Invite a friend to sign up for a free trial of ExaVault. Send a [referral](/lp/referafriend/) email to an email address. If the recipient signs up for ExaVault, we'll apply a credit to your account for the referral.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_referral_email_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param SendReferralEmailRequestBody body:
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_referral_email" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `send_referral_email`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `send_referral_email`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/email/referral', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_welcome_email(self, ev_api_key, ev_access_token, username, **kwargs):  # noqa: E501
        """Resend welcome email to specific user  # noqa: E501

        Send a welcome email to a user. The contents of the welcome email can be set by [PATCH /accounts](#operation/updateAccount).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_welcome_email(ev_api_key, ev_access_token, username, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param str username: A username to send the welcome email to. (required)
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_welcome_email_with_http_info(ev_api_key, ev_access_token, username, **kwargs)  # noqa: E501
        else:
            (data) = self.send_welcome_email_with_http_info(ev_api_key, ev_access_token, username, **kwargs)  # noqa: E501
            return data

    def send_welcome_email_with_http_info(self, ev_api_key, ev_access_token, username, **kwargs):  # noqa: E501
        """Resend welcome email to specific user  # noqa: E501

        Send a welcome email to a user. The contents of the welcome email can be set by [PATCH /accounts](#operation/updateAccount).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_welcome_email_with_http_info(ev_api_key, ev_access_token, username, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param str username: A username to send the welcome email to. (required)
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'username']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_welcome_email" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `send_welcome_email`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `send_welcome_email`")  # noqa: E501
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `send_welcome_email`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'username' in params:
            path_params['username'] = params['username']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/email/welcome/{username}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from exavault.api_client import ApiClient


class EmailListsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_email_list(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Create new email list  # noqa: E501

        Create a new email list. Among other things, email lists can be used to send files or share folders with a group of email addresses at once.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_email_list(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param AddEmailListRequestBody body:
        :return: EmailListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_email_list_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.add_email_list_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def add_email_list_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Create new email list  # noqa: E501

        Create a new email list. Among other things, email lists can be used to send files or share folders with a group of email addresses at once.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_email_list_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param AddEmailListRequestBody body:
        :return: EmailListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_email_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `add_email_list`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `add_email_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/email-lists', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmailListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_email_list_by_id(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Delete an email group with given id  # noqa: E501

        Permanently delete an email group. This action is not reversible. We recommend making a user confirm this action before sending the API call.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_email_list_by_id(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: ID of the email list to delete (required)
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_email_list_by_id_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_email_list_by_id_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
            return data

    def delete_email_list_by_id_with_http_info(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Delete an email group with given id  # noqa: E501

        Permanently delete an email group. This action is not reversible. We recommend making a user confirm this action before sending the API call.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_email_list_by_id_with_http_info(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: ID of the email list to delete (required)
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_email_list_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `delete_email_list_by_id`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `delete_email_list_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_email_list_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/email-lists/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_email_list_by_id(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Get individual email group  # noqa: E501

        Retrieve all the details of a specific email list including it's name, when it was created and all the email addresses that belong to the group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_email_list_by_id(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: ID of the email list to return. (required)
        :param str include: Related record types to include in the response. Valid option is `ownerUser`
        :return: EmailListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_email_list_by_id_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_email_list_by_id_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
            return data

    def get_email_list_by_id_with_http_info(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Get individual email group  # noqa: E501

        Retrieve all the details of a specific email list including it's name, when it was created and all the email addresses that belong to the group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_email_list_by_id_with_http_info(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: ID of the email list to return. (required)
        :param str include: Related record types to include in the response. Valid option is `ownerUser`
        :return: EmailListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'id', 'include']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_email_list_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `get_email_list_by_id`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `get_email_list_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_email_list_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'include' in params:
            query_params.append(('include', params['include']))  # noqa: E501

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/email-lists/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmailListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_email_lists(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get all email groups  # noqa: E501

        List all email groups for authenticated user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_email_lists(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param str include: Related record types to include in the response. Valid option is `ownerUser`
        :return: EmailListCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_email_lists_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_email_lists_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def get_email_lists_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get all email groups  # noqa: E501

        List all email groups for authenticated user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_email_lists_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param str include: Related record types to include in the response. Valid option is `ownerUser`
        :return: EmailListCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'include']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_email_lists" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `get_email_lists`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `get_email_lists`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'include' in params:
            query_params.append(('include', params['include']))  # noqa: E501

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/email-lists', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmailListCollectionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_email_list_by_id(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Update an email group  # noqa: E501

        Add or remove emails from an email list that can be used to send and share files with groups.   **Notes**  *This call will **replace** your current email list in its entirety.* If you want to keep any existing emails on the list, be sure to submit the call with any current emails you want to keep on the list.    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_email_list_by_id(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: ID of the email list to update. (required)
        :param UpdateEmailListRequestBody body:
        :return: EmailListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_email_list_by_id_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_email_list_by_id_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
            return data

    def update_email_list_by_id_with_http_info(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Update an email group  # noqa: E501

        Add or remove emails from an email list that can be used to send and share files with groups.   **Notes**  *This call will **replace** your current email list in its entirety.* If you want to keep any existing emails on the list, be sure to submit the call with any current emails you want to keep on the list.    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_email_list_by_id_with_http_info(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: ID of the email list to update. (required)
        :param UpdateEmailListRequestBody body:
        :return: EmailListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_email_list_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `update_email_list_by_id`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `update_email_list_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_email_list_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/email-lists/{id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmailListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CallbackSettingsValuesTriggers(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'download': 'bool',
        'upload': 'bool',
        'delete': 'bool',
        'create_folder': 'bool',
        'rename': 'bool',
        'move': 'bool',
        'copy': 'bool',
        'compress': 'bool',
        'extract': 'bool',
        'share_folder': 'bool',
        'send_files': 'bool',
        'receive_files': 'bool',
        'update_share': 'bool',
        'update_receive': 'bool',
        'delete_send': 'bool',
        'delete_receive': 'bool',
        'delete_share': 'bool',
        'create_notification': 'bool',
        'update_notification': 'bool',
        'delete_notification': 'bool',
        'create_user': 'bool',
        'update_user': 'bool',
        'delete_user': 'bool',
        'user_connect': 'bool',
        'user_disconnect': 'bool'
    }

    attribute_map = {
        'download': 'download',
        'upload': 'upload',
        'delete': 'delete',
        'create_folder': 'createFolder',
        'rename': 'rename',
        'move': 'move',
        'copy': 'copy',
        'compress': 'compress',
        'extract': 'extract',
        'share_folder': 'shareFolder',
        'send_files': 'sendFiles',
        'receive_files': 'receiveFiles',
        'update_share': 'updateShare',
        'update_receive': 'updateReceive',
        'delete_send': 'deleteSend',
        'delete_receive': 'deleteReceive',
        'delete_share': 'deleteShare',
        'create_notification': 'createNotification',
        'update_notification': 'updateNotification',
        'delete_notification': 'deleteNotification',
        'create_user': 'createUser',
        'update_user': 'updateUser',
        'delete_user': 'deleteUser',
        'user_connect': 'userConnect',
        'user_disconnect': 'userDisconnect'
    }

    def __init__(self, download=None, upload=None, delete=None, create_folder=None, rename=None, move=None, copy=None, compress=None, extract=None, share_folder=None, send_files=None, receive_files=None, update_share=None, update_receive=None, delete_send=None, delete_receive=None, delete_share=None, create_notification=None, update_notification=None, delete_notification=None, create_user=None, update_user=None, delete_user=None, user_connect=None, user_disconnect=None):  # noqa: E501
        """CallbackSettingsValuesTriggers - a model defined in Swagger"""  # noqa: E501
        self._download = None
        self._upload = None
        self._delete = None
        self._create_folder = None
        self._rename = None
        self._move = None
        self._copy = None
        self._compress = None
        self._extract = None
        self._share_folder = None
        self._send_files = None
        self._receive_files = None
        self._update_share = None
        self._update_receive = None
        self._delete_send = None
        self._delete_receive = None
        self._delete_share = None
        self._create_notification = None
        self._update_notification = None
        self._delete_notification = None
        self._create_user = None
        self._update_user = None
        self._delete_user = None
        self._user_connect = None
        self._user_disconnect = None
        self.discriminator = None
        if download is not None:
            self.download = download
        if upload is not None:
            self.upload = upload
        if delete is not None:
            self.delete = delete
        if create_folder is not None:
            self.create_folder = create_folder
        if rename is not None:
            self.rename = rename
        if move is not None:
            self.move = move
        if copy is not None:
            self.copy = copy
        if compress is not None:
            self.compress = compress
        if extract is not None:
            self.extract = extract
        if share_folder is not None:
            self.share_folder = share_folder
        if send_files is not None:
            self.send_files = send_files
        if receive_files is not None:
            self.receive_files = receive_files
        if update_share is not None:
            self.update_share = update_share
        if update_receive is not None:
            self.update_receive = update_receive
        if delete_send is not None:
            self.delete_send = delete_send
        if delete_receive is not None:
            self.delete_receive = delete_receive
        if delete_share is not None:
            self.delete_share = delete_share
        if create_notification is not None:
            self.create_notification = create_notification
        if update_notification is not None:
            self.update_notification = update_notification
        if delete_notification is not None:
            self.delete_notification = delete_notification
        if create_user is not None:
            self.create_user = create_user
        if update_user is not None:
            self.update_user = update_user
        if delete_user is not None:
            self.delete_user = delete_user
        if user_connect is not None:
            self.user_connect = user_connect
        if user_disconnect is not None:
            self.user_disconnect = user_disconnect

    @property
    def download(self):
        """Gets the download of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The download of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._download

    @download.setter
    def download(self, download):
        """Sets the download of this CallbackSettingsValuesTriggers.


        :param download: The download of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._download = download

    @property
    def upload(self):
        """Gets the upload of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The upload of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._upload

    @upload.setter
    def upload(self, upload):
        """Sets the upload of this CallbackSettingsValuesTriggers.


        :param upload: The upload of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._upload = upload

    @property
    def delete(self):
        """Gets the delete of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The delete of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """Sets the delete of this CallbackSettingsValuesTriggers.


        :param delete: The delete of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._delete = delete

    @property
    def create_folder(self):
        """Gets the create_folder of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The create_folder of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._create_folder

    @create_folder.setter
    def create_folder(self, create_folder):
        """Sets the create_folder of this CallbackSettingsValuesTriggers.


        :param create_folder: The create_folder of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._create_folder = create_folder

    @property
    def rename(self):
        """Gets the rename of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The rename of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._rename

    @rename.setter
    def rename(self, rename):
        """Sets the rename of this CallbackSettingsValuesTriggers.


        :param rename: The rename of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._rename = rename

    @property
    def move(self):
        """Gets the move of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The move of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._move

    @move.setter
    def move(self, move):
        """Sets the move of this CallbackSettingsValuesTriggers.


        :param move: The move of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._move = move

    @property
    def copy(self):
        """Gets the copy of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The copy of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._copy

    @copy.setter
    def copy(self, copy):
        """Sets the copy of this CallbackSettingsValuesTriggers.


        :param copy: The copy of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._copy = copy

    @property
    def compress(self):
        """Gets the compress of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The compress of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._compress

    @compress.setter
    def compress(self, compress):
        """Sets the compress of this CallbackSettingsValuesTriggers.


        :param compress: The compress of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._compress = compress

    @property
    def extract(self):
        """Gets the extract of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The extract of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._extract

    @extract.setter
    def extract(self, extract):
        """Sets the extract of this CallbackSettingsValuesTriggers.


        :param extract: The extract of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._extract = extract

    @property
    def share_folder(self):
        """Gets the share_folder of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The share_folder of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._share_folder

    @share_folder.setter
    def share_folder(self, share_folder):
        """Sets the share_folder of this CallbackSettingsValuesTriggers.


        :param share_folder: The share_folder of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._share_folder = share_folder

    @property
    def send_files(self):
        """Gets the send_files of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The send_files of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._send_files

    @send_files.setter
    def send_files(self, send_files):
        """Sets the send_files of this CallbackSettingsValuesTriggers.


        :param send_files: The send_files of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._send_files = send_files

    @property
    def receive_files(self):
        """Gets the receive_files of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The receive_files of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._receive_files

    @receive_files.setter
    def receive_files(self, receive_files):
        """Sets the receive_files of this CallbackSettingsValuesTriggers.


        :param receive_files: The receive_files of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._receive_files = receive_files

    @property
    def update_share(self):
        """Gets the update_share of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The update_share of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._update_share

    @update_share.setter
    def update_share(self, update_share):
        """Sets the update_share of this CallbackSettingsValuesTriggers.


        :param update_share: The update_share of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._update_share = update_share

    @property
    def update_receive(self):
        """Gets the update_receive of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The update_receive of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._update_receive

    @update_receive.setter
    def update_receive(self, update_receive):
        """Sets the update_receive of this CallbackSettingsValuesTriggers.


        :param update_receive: The update_receive of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._update_receive = update_receive

    @property
    def delete_send(self):
        """Gets the delete_send of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The delete_send of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._delete_send

    @delete_send.setter
    def delete_send(self, delete_send):
        """Sets the delete_send of this CallbackSettingsValuesTriggers.


        :param delete_send: The delete_send of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._delete_send = delete_send

    @property
    def delete_receive(self):
        """Gets the delete_receive of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The delete_receive of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._delete_receive

    @delete_receive.setter
    def delete_receive(self, delete_receive):
        """Sets the delete_receive of this CallbackSettingsValuesTriggers.


        :param delete_receive: The delete_receive of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._delete_receive = delete_receive

    @property
    def delete_share(self):
        """Gets the delete_share of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The delete_share of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._delete_share

    @delete_share.setter
    def delete_share(self, delete_share):
        """Sets the delete_share of this CallbackSettingsValuesTriggers.


        :param delete_share: The delete_share of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._delete_share = delete_share

    @property
    def create_notification(self):
        """Gets the create_notification of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The create_notification of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._create_notification

    @create_notification.setter
    def create_notification(self, create_notification):
        """Sets the create_notification of this CallbackSettingsValuesTriggers.


        :param create_notification: The create_notification of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._create_notification = create_notification

    @property
    def update_notification(self):
        """Gets the update_notification of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The update_notification of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._update_notification

    @update_notification.setter
    def update_notification(self, update_notification):
        """Sets the update_notification of this CallbackSettingsValuesTriggers.


        :param update_notification: The update_notification of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._update_notification = update_notification

    @property
    def delete_notification(self):
        """Gets the delete_notification of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The delete_notification of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._delete_notification

    @delete_notification.setter
    def delete_notification(self, delete_notification):
        """Sets the delete_notification of this CallbackSettingsValuesTriggers.


        :param delete_notification: The delete_notification of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._delete_notification = delete_notification

    @property
    def create_user(self):
        """Gets the create_user of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The create_user of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._create_user

    @create_user.setter
    def create_user(self, create_user):
        """Sets the create_user of this CallbackSettingsValuesTriggers.


        :param create_user: The create_user of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._create_user = create_user

    @property
    def update_user(self):
        """Gets the update_user of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The update_user of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._update_user

    @update_user.setter
    def update_user(self, update_user):
        """Sets the update_user of this CallbackSettingsValuesTriggers.


        :param update_user: The update_user of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._update_user = update_user

    @property
    def delete_user(self):
        """Gets the delete_user of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The delete_user of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._delete_user

    @delete_user.setter
    def delete_user(self, delete_user):
        """Sets the delete_user of this CallbackSettingsValuesTriggers.


        :param delete_user: The delete_user of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._delete_user = delete_user

    @property
    def user_connect(self):
        """Gets the user_connect of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The user_connect of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._user_connect

    @user_connect.setter
    def user_connect(self, user_connect):
        """Sets the user_connect of this CallbackSettingsValuesTriggers.


        :param user_connect: The user_connect of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._user_connect = user_connect

    @property
    def user_disconnect(self):
        """Gets the user_disconnect of this CallbackSettingsValuesTriggers.  # noqa: E501


        :return: The user_disconnect of this CallbackSettingsValuesTriggers.  # noqa: E501
        :rtype: bool
        """
        return self._user_disconnect

    @user_disconnect.setter
    def user_disconnect(self, user_disconnect):
        """Sets the user_disconnect of this CallbackSettingsValuesTriggers.


        :param user_disconnect: The user_disconnect of this CallbackSettingsValuesTriggers.  # noqa: E501
        :type: bool
        """

        self._user_disconnect = user_disconnect

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CallbackSettingsValuesTriggers, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CallbackSettingsValuesTriggers):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ShareRecipient(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'share_id': 'str',
        'type': 'str',
        'hash': 'str',
        'email': 'str',
        'sent': 'bool',
        'received': 'bool',
        'created': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'share_id': 'shareId',
        'type': 'type',
        'hash': 'hash',
        'email': 'email',
        'sent': 'sent',
        'received': 'received',
        'created': 'created'
    }

    def __init__(self, id=None, share_id=None, type=None, hash=None, email=None, sent=None, received=None, created=None):  # noqa: E501
        """ShareRecipient - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._share_id = None
        self._type = None
        self._hash = None
        self._email = None
        self._sent = None
        self._received = None
        self._created = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if share_id is not None:
            self.share_id = share_id
        if type is not None:
            self.type = type
        if hash is not None:
            self.hash = hash
        if email is not None:
            self.email = email
        if sent is not None:
            self.sent = sent
        if received is not None:
            self.received = received
        if created is not None:
            self.created = created

    @property
    def id(self):
        """Gets the id of this ShareRecipient.  # noqa: E501

        ID of the recipient.  # noqa: E501

        :return: The id of this ShareRecipient.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ShareRecipient.

        ID of the recipient.  # noqa: E501

        :param id: The id of this ShareRecipient.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def share_id(self):
        """Gets the share_id of this ShareRecipient.  # noqa: E501

        ID of the share that the recipoient belongs to.  # noqa: E501

        :return: The share_id of this ShareRecipient.  # noqa: E501
        :rtype: str
        """
        return self._share_id

    @share_id.setter
    def share_id(self, share_id):
        """Sets the share_id of this ShareRecipient.

        ID of the share that the recipoient belongs to.  # noqa: E501

        :param share_id: The share_id of this ShareRecipient.  # noqa: E501
        :type: str
        """

        self._share_id = share_id

    @property
    def type(self):
        """Gets the type of this ShareRecipient.  # noqa: E501

        Type of the recipient.  # noqa: E501

        :return: The type of this ShareRecipient.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ShareRecipient.

        Type of the recipient.  # noqa: E501

        :param type: The type of this ShareRecipient.  # noqa: E501
        :type: str
        """
        allowed_values = ["owner", "direct"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def hash(self):
        """Gets the hash of this ShareRecipient.  # noqa: E501

        Share hash.  # noqa: E501

        :return: The hash of this ShareRecipient.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this ShareRecipient.

        Share hash.  # noqa: E501

        :param hash: The hash of this ShareRecipient.  # noqa: E501
        :type: str
        """

        self._hash = hash

    @property
    def email(self):
        """Gets the email of this ShareRecipient.  # noqa: E501

        Recipient email address.  # noqa: E501

        :return: The email of this ShareRecipient.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ShareRecipient.

        Recipient email address.  # noqa: E501

        :param email: The email of this ShareRecipient.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def sent(self):
        """Gets the sent of this ShareRecipient.  # noqa: E501

        Set to true if invite email was sent; false otherwise.  # noqa: E501

        :return: The sent of this ShareRecipient.  # noqa: E501
        :rtype: bool
        """
        return self._sent

    @sent.setter
    def sent(self, sent):
        """Sets the sent of this ShareRecipient.

        Set to true if invite email was sent; false otherwise.  # noqa: E501

        :param sent: The sent of this ShareRecipient.  # noqa: E501
        :type: bool
        """

        self._sent = sent

    @property
    def received(self):
        """Gets the received of this ShareRecipient.  # noqa: E501

        Set to true if recipient has accessed the share. Note this is set to true when the recipient clicks the link to access the share; not when they download a file.  # noqa: E501

        :return: The received of this ShareRecipient.  # noqa: E501
        :rtype: bool
        """
        return self._received

    @received.setter
    def received(self, received):
        """Sets the received of this ShareRecipient.

        Set to true if recipient has accessed the share. Note this is set to true when the recipient clicks the link to access the share; not when they download a file.  # noqa: E501

        :param received: The received of this ShareRecipient.  # noqa: E501
        :type: bool
        """

        self._received = received

    @property
    def created(self):
        """Gets the created of this ShareRecipient.  # noqa: E501

        Timestamp of adding recipient to the share.  # noqa: E501

        :return: The created of this ShareRecipient.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ShareRecipient.

        Timestamp of adding recipient to the share.  # noqa: E501

        :param created: The created of this ShareRecipient.  # noqa: E501
        :type: datetime
        """

        self._created = created

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ShareRecipient, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShareRecipient):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
